clear
set more off

import excel using pa_reimb_hrr_2008.xls, clear
keep A B C D E F
rename A hrrnum
rename B hrrname
rename C state
rename D N
rename E tot_reimb
rename F tot_reimb_pr_adj
drop if _n < 3
destring hrrnum N tot_reimb tot_reimb_pr_adj, replace
merge 1:1 hrrnum using avgs, keep(match)
	drop _merge
qui summ hcccom [aw=N]
replace hcccom = hcccom/r(mean)
merge 1:1 hrrnum using posts, keep(match)
	drop _merge	
gen avg_riskscore = hcccom
gen adj_factor = exp(-post)
gen adj_riskscore = avg_riskscore*adj_factor

summ avg_riskscore
summ adj_riskscore

qui summ avg_riskscore if hrrname == "El Paso"
local elpaso_x = r(mean)
qui summ adj_riskscore if hrrname == "El Paso"
local elpaso_y = r(mean)
qui summ avg_riskscore if hrrname == "McAllen"
local mcallen_x = r(mean)
qui summ adj_riskscore if hrrname == "McAllen"
local mcallen_y = r(mean)
scatter adj_riskscore avg_riskscore if hrrname != "El Paso" & hrrname !="McAllen", color(emidblue) msize(small) || ///
	scatter adj_riskscore avg_riskscore if hrrname == "El Paso" | hrrname =="McAllen", color(maroon) msize(small) || ///
	function y = x, ra(0.8 1.35) color(black) lpattern(dash) || lfit adj_riskscore avg_riskscore, lcolor(black) ///
	xlab(0.8(0.1)1.35) ylab(0.8(0.1)1.35) || pci `elpaso_y' `elpaso_x' 0.875 0.935, color(maroon) || pci `mcallen_y' `mcallen_x' 1.07 1.24, color(maroon) ///
	xline(1, lcolor(gs12) lwidth(vthin)) yline(1, lcolor(gs12) lwidth(vthin)) scheme(s1color) legend(order(3 4) label(3 "45 degree line") label(4 "Regression line")) aspect(0.6) xtitle("Average unadjusted risk score in HRR") ytitle("Average adjusted risk score in HRR") ///
	text(0.963 0.812 "St. Paul,", size(small)) text(0.94 0.823 "MN", size(small)) text(1.18 1.31 "Miami, FL", size(small)) text(1.06 1.28 "McAllen, TX", size(small))  text(0.86 0.94 "El Paso, TX", size(small))
graph export scatter.wmf, replace

sort hrrnum
label variable hrrnum "HRR ID"
label variable hrrname "HRR name"
label variable state "HRR state"
label variable avg_riskscore "Average risk score"
label variable adj_factor "Adjustment factor"
label variable adj_riskscore "Adjusted average risk score"
export excel hrrname state hrrnum avg_riskscore adj_factor adj_riskscore using RISK_adjustment_factors_lookup.xls, replace firstrow(varlabels)
